package pay

import (
	"net/http"

	"ycc-server/app/main/api/internal/logic/pay"
	"ycc-server/app/main/api/internal/svc"
	"ycc-server/app/main/api/internal/types"
	"ycc-server/common/result"
	"ycc-server/pkg/lzkit/validator"

	"github.com/zeromicro/go-zero/rest/httpx"
)

func PaymentCheckHandler(svcCtx *svc.ServiceContext) http.HandlerFunc {
	return func(w http.ResponseWriter, r *http.Request) {
		var req types.PaymentCheckReq
		if err := httpx.Parse(r, &req); err != nil {
			result.ParamErrorResult(r, w, err)
			return
		}
		if err := validator.Validate(req); err != nil {
			result.ParamValidateErrorResult(r, w, err)
			return
		}
		l := pay.NewPaymentCheckLogic(r.Context(), svcCtx)
		resp, err := l.PaymentCheck(&req)
		result.HttpResult(r, w, resp, err)
	}
}
